@@ -12,15 +12,9 @@ class Spreadsheet(WedocApiBase):
         self.sheet_metadata = None
 
     def get_sheet_properties(self) -> dict:
-        """
-        获取表格行列信息
+        """获取表格行列信息
 
         使用示例
-
-        >>> from wedoc import WedocClient
-        >>> client = WedocClient("corpid", "corpsecret")
-        >>> wb = client.workbook("docid")
-        >>> wb.get_sheet_properties()
         """
 
         api = "/wedoc/spreadsheet/get_sheet_properties"
@@ -279,7 +273,6 @@ class Spreadsheet(WedocApiBase):
                 },
             ],
         }
-        print(json.dumps(pyload))
 
         res = self.batch_update(pyload)
         return res
@@ -308,7 +301,6 @@ class Spreadsheet(WedocApiBase):
                 },
             ],
         }
-        print(json.dumps(pyload))
 
         res = self.batch_update(pyload)
         return res
@@ -391,6 +383,31 @@ class Spreadsheet(WedocApiBase):
 
         return [item[0] for item in data]
 
+    def append_row(self, data, sheet_name=None):
+        sheet_name = sheet_name if sheet_name else self.get_active_sheet()
+        sheet_id = self.get_sheet_id(sheet_name)
+        row_count = self.get_row_count(sheet_name)
+
+        row_data = [{"cell_value": {"text": item}} for item in data]
+
+        pyload = {
+            "docid": self.docid,
+            "requests": [
+                {
+                    "update_range_request": {
+                        "sheet_id": sheet_id,
+                        "grid_data": {
+                            "start_row": row_count,
+                            "start_column": 0,
+                            "rows": [{"values": row_data}],
+                        },
+                    }
+                },
+            ],
+        }
+        res = self.batch_update(pyload)
+        return res
+
     def delete_row(self, start_index, end_index, sheet_name=None):
         """
         删除行
@@ -414,7 +431,12 @@ class Spreadsheet(WedocApiBase):
         return res
 
     def delete_column(self, start_index, end_index, sheet_name=None):
-        """删除列"""
+        """删除列
+
+        Attributes:
+            start_index (str): 开始删除的列名. 默认为空.
+
+        """
         sheet_name = sheet_name if sheet_name else self.get_active_sheet()
         sheet_id = self.get_sheet_id(sheet_name)
         pyload = {
